#[cfg(feature = "cors-middleware")]
pub use cors::{Middleware as CorsMiddleware, MiddlewareLayer as CorsLayer};

#[cfg(feature = "cors-middleware")]
mod cors;
